==> h-vue3-components-dev-1.0.11.tgz: package/es/src/packages/components/forms/formItem/FormItem.vue.js <==
import { inject, computed, ref, watch, resolveComponent, openBlock, createElementBlock, normalizeClass, createBlock, resolveDynamicComponent, unref, createSlots, withCtx, createElementVNode, createVNode, toDisplayString, renderSlot, Fragment, mergeProps, isRef, createTextVNode } from "vue";
import "../../../store/index.js";
import components from "../../index.js";
import { getContentTryIn18n, getLabelContent } from "../../../utils/i18nUtil.js";
import { getLibraryOptionData4Select, getLibraryOptionData4CheckboxRadio } from "../../../utils/libraryUtil.js";
import { tableFormatter } from "../../table/table.js";
import { useRoute } from "vue-router";
const _hoisted_1 = { key: 1 }, _hoisted_2 = { class: "h-form-error" }, _hoisted_3 = {
  key: 1,
  class: "layout-form-text"
}, _sfc_main = {
  __name: "FormItem",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: Object,
    query: {
      type: String,
      default: ""
    },
    pramDicItem: {
      type: Array,
      default() {
        return [];
      }
    },
    modelValue: Object
  },
  emits: ["update:modelValue"],
  setup(__props, { expose: __expose, emit: __emit }) {
    const route = useRoute(), currentEditFieldName = inject("currentEditFieldName"), props = __props, emit = __emit, comp = computed(() => components[props.option.fieldType]), compValue = computed({
      get: () => props.modelValue[props.option.fieldName],
      set: (e) => {
        if (props.option.isDialog === !0) {
          let o = e.split("@@@");
          props.option.fieldDesc && (props.modelValue[props.option.fieldDesc] = o[1]), props.modelValue[props.option.fieldName] = o[0];
        } else
          props.modelValue[props.option.fieldName] = e;
        currentEditFieldName && (currentEditFieldName.value = props.option.fieldName), emit("update:modelValue", props.modelValue);
      }
    }), selectOptions = ref([]);
    props.query == "query" && (props.option.customOptions ? selectOptions.value = unique(props.option.customOptions) : props.option.optionType === "1" ? selectOptions.value = unique(props.option.dicItem) : props.option.optionType === "2" ? selectOptions.value = unique(props.pramDicItem) : props.option.optionType === "3" && (props.option.fieldType == "select" || props.option.fieldType == "multipleSelection" ? getLibraryOptionData4Select(
      props.modelValue,
      props.option,
      null,
      selectOptions
    ) : (props.option.fieldType == "radio" || props.option.fieldType == "checkbox") && getLibraryOptionData4CheckboxRadio(
      props.modelValue,
      props.option,
      selectOptions
    )));
    function unique(e) {
      const o = /* @__PURE__ */ new Map();
      return e.filter((p) => !o.has(p.optCode) && o.set(p.optCode, 1));
    }
    function getLabelText() {
      return getLabelContent(props.option) + (props.query == "query" ? " :" : "");
    }
    let itemRefs = {};
    const setItemRef = (e) => {
      itemRefs[props.option.fieldName] = e;
    }, formData = inject("formData"), getFormValue = inject("getFormValue");
    watch(
      formData,
      (e) => {
        calc();
      },
      {
        deep: !0,
        immediate: !0
      }
    );
    function calc() {
      let calcExpr = props.option.autoCalc;
      if (calcExpr) {
        let reg = /[^\{\}]+(?=\})/g, paramArr = calcExpr.match(reg);
        for (let e of paramArr) {
          let o = getFormValue(e);
          route && ((o === void 0 || o === "") && (o = route.query[e]), (o === void 0 || o === "") && (o = route.params[e])), calcExpr = calcExpr.replace(
            new RegExp("\\$\\{" + e + "\\}", "gm"),
            o
          );
        }
        let value = eval(calcExpr);
        isNaN(value) && (value = 0), props.option.fieldType === "text" && value && (props.option.dataType === "money(yuan)" ? value = formUtil.formatMoney(value) : props.option.dataType === "money(qian)" ? (value = formUtil.numDiv(value, 1e3), value = formUtil.formatMoney(value)) : props.option.dataType === "money(wan)" ? (value = formUtil.numDiv(value, 1e4), value = formUtil.formatMoney(value)) : props.option.dataType === "money(baiwan)" ? (value = formUtil.numDiv(value, 1e6), value = formUtil.formatMoney(value)) : props.option.dataType === "money(yi)" ? (value = formUtil.numDiv(value, 1e8), value = formUtil.formatMoney(value)) : props.option.dataType === "percentile" ? value = formUtil.numMulti(value, 100) : props.option.dataType === "thousand" ? value = formUtil.numMulti(value, 1e3) : props.option.dataType === "tenThousand" && (value = formUtil.numMulti(value, 1e4))), compValue.value = value;
      }
    }
    function getFormItem() {
      return {
        ref: itemRefs[props.option.fieldName],
        fieldName: props.option.fieldName
      };
    }
    return __expose({
      getFormItem
    }), (e, o) => {
      const p = resolveComponent("h-tooltip"), r = resolveComponent("Warning"), l = resolveComponent("el-icon"), n = resolveComponent("el-form-item");
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["h-form-item", props.option.fieldType || "empty"])
      }, [
        props.option.fieldType == "label" ? (openBlock(), createBlock(resolveDynamicComponent(unref(comp)), {
          key: 0,
          option: props.option
        }, null, 8, ["option"])) : props.option.fieldType === "empty" || !props.option.fieldType ? (openBlock(), createElementBlock("div", _hoisted_1)) : (openBlock(), createBlock(n, {
          key: 2,
          label: getLabelText(),
          prop: props.option.fieldName,
          class: normalizeClass({
            "h-form-group": props.option.fieldType === "group",
            "only-label": props.option.showContents === 2,
            "only-input": props.option.showContents === 3,
            "item-enable": props.option.disabled || props.option.readOnly && props.option.notShowReadOnlyStyle !== !0
          })
        }, createSlots({
          error: withCtx((t) => [
            createElementVNode("div", _hoisted_2, [
              createVNode(l, null, {
                default: withCtx(() => [
                  createVNode(r)
                ]),
                _: 1
              }),
              createElementVNode("span", null, toDisplayString(unref(getContentTryIn18n)(t.error)), 1)
            ])
          ]),
          default: withCtx(() => [
            renderSlot(e.$slots, "default", {}, () => [
              props.query == "query" ? (openBlock(), createElementBlock(Fragment, { key: 0 }, [
                props.option.fieldType == "cascader" || props.option.fieldType == "area" || props.option.fieldType == "trade" ? (openBlock(), createBlock(resolveDynamicComponent(unref(comp)), mergeProps({
                  key: 0,
                  modelValue: unref(compValue),
                  "onUpdate:modelValue": o[0] || (o[0] = (t) => isRef(compValue) ? compValue.value = t : null),
                  option: props.option,
                  query: props.query
                }, e.$attrs), null, 16, ["modelValue", "option", "query"])) : (openBlock(), createElementBlock("div", _hoisted_3, toDisplayString(unref(tableFormatter)(unref(compValue), props.option, unref(selectOptions))), 1))
              ], 64)) : (openBlock(), createBlock(resolveDynamicComponent(unref(comp)), mergeProps({
                key: 1,
                ref: setItemRef,
                modelValue: unref(compValue),
                "onUpdate:modelValue": o[1] || (o[1] = (t) => isRef(compValue) ? compValue.value = t : null),
                option: props.option,
                event: props.event,
                pramDicItem: props.pramDicItem
              }, e.$attrs), null, 16, ["modelValue", "option", "event", "pramDicItem"]))
            ])
          ]),
          _: 2
        }, [
          props.option.warning && props.option.warnName != null ? {
            name: "label",
            fn: withCtx(() => [
              createElementVNode("span", null, toDisplayString(unref(getLabelContent)(props.option)), 1),
              createVNode(p, null, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(props.option.warnName), 1)
                ]),
                _: 1
              })
            ]),
            key: "0"
          } : void 0
        ]), 1032, ["label", "prop", "class"]))
      ], 2);
    };
  }
};
export {
  _sfc_main as default
};

==> h-vue3-components-dev-1.0.30.tgz: package/es/src/packages/components/forms/formItem/FormItem.vue.js <==
import "../../../../../node_modules/element-plus/theme-chalk/base.css.js";
import "../../../../../node_modules/element-plus/theme-chalk/el-form-item.css.js";
import "../../../../../node_modules/element-plus/theme-chalk/el-icon.css.js";
import { inject, computed, ref, watch, resolveComponent, openBlock, createElementBlock, normalizeClass, createBlock, resolveDynamicComponent, unref, createSlots, withCtx, createElementVNode, createVNode, toDisplayString, renderSlot, Fragment, mergeProps, isRef, createTextVNode } from "vue";
import "../../../store/index.js";
import * as index from "../../index.js";
import { getContentTryIn18n, getLabelContent } from "../../../utils/i18nUtil.js";
import { getLibraryOptionData4Select, getLibraryOptionData4CheckboxRadio } from "../../../utils/libraryUtil.js";
import { tableFormatter } from "../../table/table.js";
import { useRoute } from "vue-router";
import { ElIcon } from "../../../../../node_modules/element-plus/es/components/icon/index.js";
import { ElFormItem } from "../../../../../node_modules/element-plus/es/components/form/index.js";
const _hoisted_1 = { key: 1 }, _hoisted_2 = { class: "h-form-error" }, _hoisted_3 = {
  key: 1,
  class: "layout-form-text"
}, _sfc_main = {
  __name: "FormItem",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: Object,
    query: {
      type: String,
      default: ""
    },
    pramDicItem: {
      type: Array,
      default() {
        return [];
      }
    },
    modelValue: Object
  },
  emits: ["update:modelValue"],
  setup(__props, { expose: __expose, emit: __emit }) {
    const route = useRoute(), currentEditFieldName = inject("currentEditFieldName"), props = __props, emit = __emit, comp = computed(() => index[props.option.fieldType]), compValue = computed({
      get: () => props.modelValue[props.option.fieldName],
      set: (e) => {
        if (props.option.isDialog === !0) {
          let o = e.split("@@@");
          props.option.fieldDesc && (props.modelValue[props.option.fieldDesc] = o[1]), props.modelValue[props.option.fieldName] = o[0];
        } else
          props.modelValue[props.option.fieldName] = e;
        currentEditFieldName && (currentEditFieldName.value = props.option.fieldName), emit("update:modelValue", props.modelValue);
      }
    }), selectOptions = ref([]);
    props.query == "query" && (props.option.customOptions ? selectOptions.value = unique(props.option.customOptions) : props.option.optionType === "1" ? selectOptions.value = unique(props.option.dicItem) : props.option.optionType === "2" ? selectOptions.value = unique(props.pramDicItem) : props.option.optionType === "3" && (props.option.fieldType == "select" || props.option.fieldType == "multipleSelection" ? getLibraryOptionData4Select(
      props.modelValue,
      props.option,
      null,
      selectOptions
    ) : (props.option.fieldType == "radio" || props.option.fieldType == "checkbox") && getLibraryOptionData4CheckboxRadio(
      props.modelValue,
      props.option,
      selectOptions
    )));
    function unique(e) {
      const o = /* @__PURE__ */ new Map();
      return e.filter((p) => !o.has(p.optCode) && o.set(p.optCode, 1));
    }
    function getLabelText() {
      return getLabelContent(props.option) + (props.query == "query" ? " :" : "");
    }
    let itemRefs = {};
    const setItemRef = (e) => {
      itemRefs[props.option.fieldName] = e;
    }, formData = inject("formData"), getFormValue = inject("getFormValue");
    watch(
      formData,
      (e) => {
        calc();
      },
      {
        deep: !0,
        immediate: !0
      }
    );
    function calc() {
      let calcExpr = props.option.autoCalc;
      if (calcExpr) {
        let reg = /[^\{\}]+(?=\})/g, paramArr = calcExpr.match(reg);
        for (let e of paramArr) {
          let o = getFormValue(e);
          route && ((o === void 0 || o === "") && (o = route.query[e]), (o === void 0 || o === "") && (o = route.params[e])), calcExpr = calcExpr.replace(
            new RegExp("\\$\\{" + e + "\\}", "gm"),
            o
          );
        }
        let value = eval(calcExpr);
        isNaN(value) && (value = 0), props.option.fieldType === "text" && value && (props.option.dataType === "money(yuan)" ? value = formUtil.formatMoney(value) : props.option.dataType === "money(qian)" ? (value = formUtil.numDiv(value, 1e3), value = formUtil.formatMoney(value)) : props.option.dataType === "money(wan)" ? (value = formUtil.numDiv(value, 1e4), value = formUtil.formatMoney(value)) : props.option.dataType === "money(baiwan)" ? (value = formUtil.numDiv(value, 1e6), value = formUtil.formatMoney(value)) : props.option.dataType === "money(yi)" ? (value = formUtil.numDiv(value, 1e8), value = formUtil.formatMoney(value)) : props.option.dataType === "percentile" ? value = formUtil.numMulti(value, 100) : props.option.dataType === "thousand" ? value = formUtil.numMulti(value, 1e3) : props.option.dataType === "tenThousand" && (value = formUtil.numMulti(value, 1e4))), compValue.value = value;
      }
    }
    function getFormItem() {
      return {
        ref: itemRefs[props.option.fieldName],
        fieldName: props.option.fieldName
      };
    }
    return __expose({
      getFormItem
    }), (e, o) => {
      const p = resolveComponent("h-tooltip"), r = resolveComponent("Warning"), l = ElIcon, n = ElFormItem;
      return openBlock(), createElementBlock("div", {
        class: normalizeClass(["h-form-item", props.option.fieldType || "empty"])
      }, [
        props.option.fieldType == "label" ? (openBlock(), createBlock(resolveDynamicComponent(unref(comp)), {
          key: 0,
          option: props.option
        }, null, 8, ["option"])) : props.option.fieldType === "empty" || !props.option.fieldType ? (openBlock(), createElementBlock("div", _hoisted_1)) : (openBlock(), createBlock(n, {
          key: 2,
          label: getLabelText(),
          prop: props.option.fieldName,
          class: normalizeClass({
            "h-form-group": props.option.fieldType === "group",
            "only-label": props.option.showContents === 2,
            "only-input": props.option.showContents === 3,
            "item-enable": props.option.disabled || props.option.readOnly && props.option.notShowReadOnlyStyle !== !0
          })
        }, createSlots({
          error: withCtx((t) => [
            createElementVNode("div", _hoisted_2, [
              createVNode(l, null, {
                default: withCtx(() => [
                  createVNode(r)
                ]),
                _: 1
              }),
              createElementVNode("span", null, toDisplayString(unref(getContentTryIn18n)(t.error)), 1)
            ])
          ]),
          default: withCtx(() => [
            renderSlot(e.$slots, "default", {}, () => [
              props.query == "query" ? (openBlock(), createElementBlock(Fragment, { key: 0 }, [
                props.option.fieldType == "cascader" || props.option.fieldType == "area" || props.option.fieldType == "trade" ? (openBlock(), createBlock(resolveDynamicComponent(unref(comp)), mergeProps({
                  key: 0,
                  modelValue: unref(compValue),
                  "onUpdate:modelValue": o[0] || (o[0] = (t) => isRef(compValue) ? compValue.value = t : null),
                  option: props.option,
                  query: props.query
                }, e.$attrs), null, 16, ["modelValue", "option", "query"])) : (openBlock(), createElementBlock("div", _hoisted_3, toDisplayString(unref(tableFormatter)(unref(compValue), props.option, unref(selectOptions))), 1))
              ], 64)) : (openBlock(), createBlock(resolveDynamicComponent(unref(comp)), mergeProps({
                key: 1,
                ref: setItemRef,
                modelValue: unref(compValue),
                "onUpdate:modelValue": o[1] || (o[1] = (t) => isRef(compValue) ? compValue.value = t : null),
                option: props.option,
                event: props.event,
                pramDicItem: props.pramDicItem
              }, e.$attrs), null, 16, ["modelValue", "option", "event", "pramDicItem"]))
            ])
          ]),
          _: 2
        }, [
          props.option.warning && props.option.warnName != null ? {
            name: "label",
            fn: withCtx(() => [
              createElementVNode("span", null, toDisplayString(unref(getLabelContent)(props.option)), 1),
              createVNode(p, null, {
                default: withCtx(() => [
                  createTextVNode(toDisplayString(props.option.warnName), 1)
                ]),
                _: 1
              })
            ]),
            key: "0"
          } : void 0
        ]), 1032, ["label", "prop", "class"]))
      ], 2);
    };
  }
};
export {
  _sfc_main as default
};
